Welcome to ClientVPS Mirrors

Help for package WaveletETS
Type: Package
Title: Wavelet Based Error Trend Seasonality Model
Version: 0.1.0
Author: Dr. Ranjit Kumar Paul [aut], Dr. Md Yeasin [aut, cre]
Maintainer: Dr. Md Yeasin <yeasin.iasri@gmail.com>
Description: ETS stands for Error, Trend, and Seasonality, and it is a popular time series forecasting method. Wavelet decomposition can be used for denoising, compression, and feature extraction of signals. By removing the high-frequency components, wavelet decomposition can remove noise from the data while preserving important features. A hybrid Wavelet ETS (Error Trend-Seasonality) model has been developed for time series forecasting using algorithm of Anjoy and Paul (2017) <doi:10.1007/s00521-017-3289-9>.
License: GPL-3
Encoding: UTF-8
Imports: dplyr, Metrics, tseries, stats, wavelets, forecast, caretForecast
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2023-04-05 11:02:48 UTC; YEASIN
Repository: CRAN
Date/Publication: 2023-04-05 18:23:22 UTC

Wavelet Based Error Trend Seasonality Model

Description

Wavelet Based Error Trend Seasonality Model

Usage

WaveletETS(ts, split_ratio = 0.8, wlevels = 3)

Arguments

ts

Time Series Data

split_ratio

Training and Testing Split

wlevels

Number of Wavelet Levels

Value

References

Examples

library("WaveletETS")
data<- rnorm(100,100, 10)
WG<-WaveletETS(ts=data)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.